@@ -79,6 +79,7 @@ extern "C" {
 #include <netdb.h>
 #include <stdint.h>
 #include <sys/socket.h>
+#include <netinet/in.h>
 #include <unistd.h>
 #endif
 
@@ -130,7 +131,7 @@ get_from_humanReadableBookId(const std::string& humanReadableBookId) {
 static std::string getMimeTypeForFile(const std::string& filename)
 {
   std::string mimeType = "text/plain";
-  unsigned int pos = filename.find_last_of(".");
+  auto pos = filename.find_last_of(".");
 
   if (pos != std::string::npos) {
     std::string extension = filename.substr(pos + 1);
@@ -983,15 +984,15 @@ int main(int argc, char** argv)
           break;
       }
     } else {
-      if (optind <= argc) {
+      if (optind < argc) {
         if (libraryFlag) {
           libraryPath = argv[optind++];
         } else {
           while (optind < argc)
             zimPathes.push_back(std::string(argv[optind++]));
         }
-        break;
       }
+      break;
     }
   }
 
